==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1alpha1VolumeAttachmentSpecFluentImpl.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class V1alpha1VolumeAttachmentSpecFluentImpl<A extends V1alpha1VolumeAttachmentSpecFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V1alpha1VolumeAttachmentSpecFluent<A>{

    private String attacher;
    private String nodeName;
    private V1alpha1VolumeAttachmentSourceBuilder source;

    public V1alpha1VolumeAttachmentSpecFluentImpl(){
    }
    public V1alpha1VolumeAttachmentSpecFluentImpl(V1alpha1VolumeAttachmentSpec instance){
            this.withAttacher(instance.getAttacher());

            this.withNodeName(instance.getNodeName());

            this.withSource(instance.getSource());

    }

    public String getAttacher(){
            return this.attacher;
    }

    public A withAttacher(String attacher){
            this.attacher=attacher; return (A) this;
    }

    public Boolean hasAttacher(){
            return this.attacher != null;
    }

    public String getNodeName(){
            return this.nodeName;
    }

    public A withNodeName(String nodeName){
            this.nodeName=nodeName; return (A) this;
    }

    public Boolean hasNodeName(){
            return this.nodeName != null;
    }

    
/**
 * This method has been deprecated, please use method buildSource instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1VolumeAttachmentSource getSource(){
            return this.source!=null?this.source.build():null;
    }

    public V1alpha1VolumeAttachmentSource buildSource(){
            return this.source!=null?this.source.build():null;
    }

    public A withSource(V1alpha1VolumeAttachmentSource source){
            _visitables.remove(this.source);
            if (source!=null){ this.source= new V1alpha1VolumeAttachmentSourceBuilder(source); _visitables.add(this.source);} return (A) this;
    }

    public Boolean hasSource(){
            return this.source != null;
    }

    public V1alpha1VolumeAttachmentSpecFluent.SourceNested<A> withNewSource(){
            return new SourceNestedImpl();
    }

    public V1alpha1VolumeAttachmentSpecFluent.SourceNested<A> withNewSourceLike(V1alpha1VolumeAttachmentSource item){
            return new SourceNestedImpl(item);
    }

    public V1alpha1VolumeAttachmentSpecFluent.SourceNested<A> editSource(){
            return withNewSourceLike(getSource());
    }

    public V1alpha1VolumeAttachmentSpecFluent.SourceNested<A> editOrNewSource(){
            return withNewSourceLike(getSource() != null ? getSource(): new V1alpha1VolumeAttachmentSourceBuilder().build());
    }

    public V1alpha1VolumeAttachmentSpecFluent.SourceNested<A> editOrNewSourceLike(V1alpha1VolumeAttachmentSource item){
            return withNewSourceLike(getSource() != null ? getSource(): item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1alpha1VolumeAttachmentSpecFluentImpl that = (V1alpha1VolumeAttachmentSpecFluentImpl) o;
            if (attacher != null ? !attacher.equals(that.attacher) :that.attacher != null) return false;
            if (nodeName != null ? !nodeName.equals(that.nodeName) :that.nodeName != null) return false;
            if (source != null ? !source.equals(that.source) :that.source != null) return false;
            return true;
    }


    public class SourceNestedImpl<N> extends V1alpha1VolumeAttachmentSourceFluentImpl<V1alpha1VolumeAttachmentSpecFluent.SourceNested<N>> implements V1alpha1VolumeAttachmentSpecFluent.SourceNested<N>,io.kubernetes.client.fluent.Nested<N>{

            private final V1alpha1VolumeAttachmentSourceBuilder builder;
    
            SourceNestedImpl(V1alpha1VolumeAttachmentSource item){
                    this.builder = new V1alpha1VolumeAttachmentSourceBuilder(this, item);
            }
            SourceNestedImpl(){
                    this.builder = new V1alpha1VolumeAttachmentSourceBuilder(this);
            }
    
    public N and(){
            return (N) V1alpha1VolumeAttachmentSpecFluentImpl.this.withSource(builder.build());
    }
    public N endSource(){
            return and();
    }

}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1alpha1VolumeAttachmentSpecFluentImpl.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class V1alpha1VolumeAttachmentSpecFluentImpl<A extends V1alpha1VolumeAttachmentSpecFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V1alpha1VolumeAttachmentSpecFluent<A>{

    private String attacher;
    private String nodeName;
    private V1alpha1VolumeAttachmentSourceBuilder source;

    public V1alpha1VolumeAttachmentSpecFluentImpl(){
    }
    public V1alpha1VolumeAttachmentSpecFluentImpl(V1alpha1VolumeAttachmentSpec instance){
            this.withAttacher(instance.getAttacher());

            this.withNodeName(instance.getNodeName());

            this.withSource(instance.getSource());

    }

    public String getAttacher(){
            return this.attacher;
    }

    public A withAttacher(String attacher){
            this.attacher=attacher; return (A) this;
    }

    public Boolean hasAttacher(){
            return this.attacher != null;
    }

    public A withNewAttacher(String arg1){
            return (A)withAttacher(new String(arg1));
    }

    public A withNewAttacher(StringBuilder arg1){
            return (A)withAttacher(new String(arg1));
    }

    public A withNewAttacher(StringBuffer arg1){
            return (A)withAttacher(new String(arg1));
    }

    public String getNodeName(){
            return this.nodeName;
    }

    public A withNodeName(String nodeName){
            this.nodeName=nodeName; return (A) this;
    }

    public Boolean hasNodeName(){
            return this.nodeName != null;
    }

    public A withNewNodeName(String arg1){
            return (A)withNodeName(new String(arg1));
    }

    public A withNewNodeName(StringBuilder arg1){
            return (A)withNodeName(new String(arg1));
    }

    public A withNewNodeName(StringBuffer arg1){
            return (A)withNodeName(new String(arg1));
    }

    
/**
 * This method has been deprecated, please use method buildSource instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1VolumeAttachmentSource getSource(){
            return this.source!=null?this.source.build():null;
    }

    public V1alpha1VolumeAttachmentSource buildSource(){
            return this.source!=null?this.source.build():null;
    }

    public A withSource(V1alpha1VolumeAttachmentSource source){
            _visitables.get("source").remove(this.source);
            if (source!=null){ this.source= new V1alpha1VolumeAttachmentSourceBuilder(source); _visitables.get("source").add(this.source);} return (A) this;
    }

    public Boolean hasSource(){
            return this.source != null;
    }

    public V1alpha1VolumeAttachmentSpecFluent.SourceNested<A> withNewSource(){
            return new SourceNestedImpl();
    }

    public V1alpha1VolumeAttachmentSpecFluent.SourceNested<A> withNewSourceLike(V1alpha1VolumeAttachmentSource item){
            return new SourceNestedImpl(item);
    }

    public V1alpha1VolumeAttachmentSpecFluent.SourceNested<A> editSource(){
            return withNewSourceLike(getSource());
    }

    public V1alpha1VolumeAttachmentSpecFluent.SourceNested<A> editOrNewSource(){
            return withNewSourceLike(getSource() != null ? getSource(): new V1alpha1VolumeAttachmentSourceBuilder().build());
    }

    public V1alpha1VolumeAttachmentSpecFluent.SourceNested<A> editOrNewSourceLike(V1alpha1VolumeAttachmentSource item){
            return withNewSourceLike(getSource() != null ? getSource(): item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1alpha1VolumeAttachmentSpecFluentImpl that = (V1alpha1VolumeAttachmentSpecFluentImpl) o;
            if (attacher != null ? !attacher.equals(that.attacher) :that.attacher != null) return false;
            if (nodeName != null ? !nodeName.equals(that.nodeName) :that.nodeName != null) return false;
            if (source != null ? !source.equals(that.source) :that.source != null) return false;
            return true;
    }


    public class SourceNestedImpl<N> extends V1alpha1VolumeAttachmentSourceFluentImpl<V1alpha1VolumeAttachmentSpecFluent.SourceNested<N>> implements V1alpha1VolumeAttachmentSpecFluent.SourceNested<N>,io.kubernetes.client.fluent.Nested<N>{

            private final V1alpha1VolumeAttachmentSourceBuilder builder;
    
            SourceNestedImpl(V1alpha1VolumeAttachmentSource item){
                    this.builder = new V1alpha1VolumeAttachmentSourceBuilder(this, item);
            }
            SourceNestedImpl(){
                    this.builder = new V1alpha1VolumeAttachmentSourceBuilder(this);
            }
    
    public N and(){
            return (N) V1alpha1VolumeAttachmentSpecFluentImpl.this.withSource(builder.build());
    }
    public N endSource(){
            return and();
    }

}


}
